Function amazon_sp_sellers::apis::sellers_api::get_marketplace_participations
source · [−]pub async fn get_marketplace_participations(
configuration: &Configuration
) -> Result<GetMarketplaceParticipationsResponse, Error>Expand description
Returns a list of marketplaces that the seller submitting the request can sell in and information about the seller’s participation in those marketplaces. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | .016 | 15 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.